@@ -3,16 +3,16 @@ use std::{
     fmt::{Display, Formatter},
 };
 
-/// A single contiguous block of `CommitMessage` text
+/// A single contiguous block of [`CommitMessage`] text
 #[derive(Debug, PartialEq, Clone, Default)]
 pub struct Body {
     text: String,
 }
 
 impl Body {
-    /// Append one body onto another
+    /// Append one [`Body`] onto another
     ///
-    /// This is for concatenating multiple bodies together
+    /// This is for concatenating multiple [`Bodies`] together
     ///
     /// # Example
     ///
@@ -30,14 +30,14 @@ impl Body {
     /// )
     /// ```
     #[must_use]
-    pub fn append(&self, additional: &Body) -> Body {
-        Body::from(format!("{}\n{}", self.text, additional.text))
+    pub fn append(&self, additional: &Self) -> Self {
+        Self::from(format!("{}\n{}", self.text, additional.text))
     }
 
-    /// Is this body empty
+    /// Is this [`Body`] empty
     ///
-    /// Empty bodies usually indicate a paragraph break in commit messages so
-    /// it's handy to be able to see them.
+    /// An empty [`Body`] usually indicate a paragraph break in a
+    /// [`CommitMessage`] so it's handy to be able to see them.
     ///
     /// # Example
     ///
@@ -55,7 +55,7 @@ impl Body {
 
 impl From<&str> for Body {
     fn from(body: &str) -> Self {
-        Body {
+        Self {
             text: String::from(body),
         }
     }
@@ -63,7 +63,7 @@ impl From<&str> for Body {
 
 impl From<String> for Body {
     fn from(body: String) -> Self {
-        Body { text: body }
+        Self { text: body }
     }
 }
 
